# YAMP

## Overview

YAMP (Yet Another Online Music Player) is an online music player for console/terminal that no one asked for.

## Installation

```
$ pip install yamp_py
```
To run the application
```
$ yamp
```
## Acknowledgments

Special thanks to [JioSaavn Unofficial API](https://saavn.dev/)

## Contributing

This project is a personal project and not actively maintained. However, contributions are welcome. If you find any bugs or have suggestions for improvements, feel free to submit a pull request or open an issue.

## License

This project is licensed under the [MIT License](LICENSE).